@@ -1077,10 +1077,7 @@ void MpvProxy::refreshDecode()
             PlayItemInfo currentInfo = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist()->currentInfo();
             auto codec = currentInfo.mi.videoCodec();
             auto name = _file.fileName();
-            isSoftCodec = codec.toLower().contains("wmv") || name.toLower().contains("wmv");
-#if !defined (__x86_64__)
-            isSoftCodec = isSoftCodec || codec.toLower().contains("mpeg2video");
-#endif
+            isSoftCodec = codec.toLower().contains("mpeg2video") || codec.toLower().contains("wmv") || name.toLower().contains("wmv");
             //探测硬解码
             if(!isSoftCodec) {
                 isSoftCodec = !isSurportHardWareDecode(codec, currentInfo.mi.width, currentInfo.mi.height);
@@ -1204,17 +1201,20 @@ void MpvProxy::play()
     bool bRawFormat = false;
     QList<QVariant> listArgs = { "loadfile" };
     QStringList listOpts = { };
+    PlayerEngine* pEngine = nullptr;
+    bool bAudio = false;
 
     if (!m_bInited) {
         firstInit();
     }
 
-    if (0 < dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist()->size()) {
-        PlayItemInfo currentInfo = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist()->currentInfo();
-        bRawFormat = currentInfo.mi.isRawFormat();
+    pEngine = dynamic_cast<PlayerEngine *>(m_pParentWidget);
+    if (pEngine && pEngine->getplaylist()->size() > 0) {
+        bRawFormat = pEngine->getplaylist()->currentInfo().mi.isRawFormat();
+        bAudio =  pEngine->currFileIsAudio();
     }
 
-    if (PlayerEngine::isAudioFile(_file.toString())) {
+    if (bAudio) {
         my_set_property(m_handle, "vo", "null");
     } else {
         my_set_property(m_handle, "vo", m_sInitVo);
@@ -1245,32 +1245,21 @@ void MpvProxy::play()
     if (!_dvdDevice.isEmpty()) {
         listOpts << QString("dvd-device=%1").arg(_dvdDevice);
     }
-
-//注：m_bHwaccelAuto 好像是废弃了,初始化为false,此处未执行
-//    if (m_bHwaccelAuto && m_bLastIsSpecficFormat) {
-//        if (!m_bIsJingJia || !utils::check_wayland_env()) {
-//            // hwdec could be disabled by some codecs, so we need to re-enable it
-//            my_set_property(m_handle, "hwdec", "auto");
-//#if defined (__mips__) || defined (__aarch64__) || defined (__sw_64__)
-//            if (!CompositingManager::get().hascard() || CompositingManager::get().isOnlySoftDecode()) {
-//                my_set_property(m_handle, "hwdec", "no");
-//            }
-//#endif
-//        }
-//    }
-//#else
-//    if (m_bHwaccelAuto) {
-//        if (CompositingManager::get().isOnlySoftDecode()) {
-//            my_set_property(m_handle, "hwdec", "no");
-//        } else {
-//            my_set_property(m_handle, "hwdec", "auto");
-//        }
-//    }
 #endif
 
     //刷新解码模式
     refreshDecode();
 
+    QFileInfo fi("/dev/mwv206_0");  // 景美驱动硬解avs2有崩溃问题
+    if (fi.exists()) {
+        QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206");
+        QString sCodec = pEngine->playlist().currentInfo().mi.videoCodec();
+        if(sdir.exists() && sCodec.contains("avs2", Qt::CaseInsensitive)) {
+             my_set_property(m_handle, "hwdec", "no");
+             my_set_property(m_handle, "vo", "gpu,x11,xv");
+        }
+    }
+
     if (listOpts.size()) {
         listArgs << "replace" << listOpts.join(',');
     }
@@ -1563,7 +1552,6 @@ void MpvProxy::stepBurstScreenshot()
         return;
     }
     emit notifyScreenshot(img, elapsed());
-
     QTimer::singleShot(0, this, &MpvProxy::stepBurstScreenshot);
 }
 
