@@ -41,6 +41,7 @@
 #include "compositing_manager.h"
 #include "dguiapplicationhelper.h"
 #include "filefilter.h"
+#include "qtplayer_proxy.h"
 
 #include <QPainterPath>
 
@@ -70,10 +71,15 @@ PlayerEngine::PlayerEngine(QWidget *parent)
     : QWidget(parent)
 {
     m_bAudio = false;
+    m_stopRunningThread = false;
     auto *l = new QVBoxLayout(this);
     l->setContentsMargins(0, 0, 0, 0);
 
-    _current = new MpvProxy(this);
+    if(CompositingManager::isMpvExists()){
+        _current = new MpvProxy(this);
+    } else {
+        _current = new QtPlayerProxy(this);
+    }
     if (_current) {
         connect(_current, &Backend::stateChanged, this, &PlayerEngine::onBackendStateChanged);
         connect(_current, &Backend::tracksChanged, this, &PlayerEngine::tracksChanged);
@@ -88,6 +94,7 @@ PlayerEngine::PlayerEngine(QWidget *parent)
         connect(_current, &Backend::mpvErrorLogsChanged, this, &PlayerEngine::mpvErrorLogsChanged);
         connect(_current, &Backend::mpvWarningLogsChanged, this, &PlayerEngine::mpvWarningLogsChanged);
         connect(_current, &Backend::urlpause, this, &PlayerEngine::urlpause);
+        connect(_current, &Backend::sigMediaError, this, &PlayerEngine::sigMediaError);
         l->addWidget(_current);
     }
 
@@ -111,15 +118,19 @@ PlayerEngine::PlayerEngine(QWidget *parent)
 
 PlayerEngine::~PlayerEngine()
 {
-    disconnect(_playlist, nullptr, nullptr, nullptr);
-    delete _playlist;
-    _playlist = nullptr;
-
+    m_stopRunningThread = true;
+    FileFilter::instance()->stopThread();
     if (_current) {
         disconnect(_current, nullptr, nullptr, nullptr);
         delete _current;
         _current = nullptr;
     }
+    
+    if (_playlist) {
+        disconnect(_playlist, nullptr, nullptr, nullptr);
+        delete _playlist;
+        _playlist = nullptr;
+    }
     qInfo() << __func__;
 }
 
@@ -167,10 +178,16 @@ bool PlayerEngine::isSubtitle(const QString &name)
 void PlayerEngine::updateSubStyles()
 {
 #ifndef _LIBDMR_
-    auto font_opt = Settings::get().settings()->option("subtitle.font.family");
-    auto font_id = font_opt->value().toInt();
-    auto font = font_opt->data("items").toStringList()[font_id];
-    auto sz = Settings::get().settings()->option("subtitle.font.size")->value().toInt();
+    QPointer<DSettingsOption> pFontOpt = Settings::get().settings()->option("subtitle.font.family");
+    QPointer<DSettingsOption> pSizeOpt = Settings::get().settings()->option("subtitle.font.size");
+    if(!pFontOpt || !pSizeOpt)
+    {
+        return;
+    }
+
+    int fontId = pFontOpt->value().toInt();
+    int size = pSizeOpt->value().toInt();
+    QString font = pFontOpt->data("items").toStringList()[fontId];
 
     if (_state != CoreState::Idle) {
         if (_playlist->current() < 0) return;
@@ -180,19 +197,20 @@ void PlayerEngine::updateSubStyles()
             vh = _playlist->currentInfo().mi.height;
         }
         double scale = vh / 720.0;
-        sz /= scale;
+        size /= scale;
         /* magic scale number 2.0 comes from my mind, test with my eyes... */
-        sz *= 2.0;
-        qInfo() << "update sub " << font << sz;
-        updateSubStyle(font, sz);
+        size *= 2.0;
+        updateSubStyle(font, size);
     }
 #endif
 }
 
 void PlayerEngine::waitLastEnd()
 {
-    if (auto *mpv = dynamic_cast<MpvProxy *>(_current)) {
+    if (MpvProxy *mpv = dynamic_cast<MpvProxy *>(_current)) {
         mpv->pollingEndOfPlayback();
+    }else if (QtPlayerProxy *qtPlayer = dynamic_cast<QtPlayerProxy *>(_current)) {
+        qtPlayer->pollingEndOfPlayback();
     }
 }
 
@@ -205,7 +223,7 @@ void PlayerEngine::onBackendStateChanged()
     case Backend::PlayState::Playing:
         _state = CoreState::Playing;
         if (_playlist->count() > 0) {
-            m_bAudio = isAudioFile(_playlist->currentInfo().mi.filePath);
+            m_bAudio = currFileIsAudio();
         }
         //playing . emit thumbnail progress mode signal with setting file
         if (old == CoreState::Idle)
@@ -519,15 +537,14 @@ void PlayerEngine::paintEvent(QPaintEvent *e)
         } else {
             QImage icon = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
             QPixmap pix = QPixmap::fromImage(icon);
-            int x = this->rect().center().x() - pix.width() / 2;
-            int y = this->rect().center().y() - pix.height() / 2;
+            QPointF pos = rect.center() - QPoint(pix.width() / 2, pix.height() / 2) / devicePixelRatioF();
 
             if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
                 p.fillRect(rect, QBrush(QColor(255, 255, 255)));
-                p.drawPixmap(x, y, pix);
+                p.drawPixmap(pos, pix);
             } else {
                 p.fillRect(rect, QBrush(QColor(0, 0, 0)));
-                p.drawPixmap(x, y, pix);
+                p.drawPixmap(pos, pix);
             }
         }
     }
@@ -783,11 +800,14 @@ QList<QUrl> PlayerEngine::addPlayFiles(const QList<QUrl> &urls)
     QList<QUrl> valids;
 
     for (QUrl url : urls) {
+        if (m_stopRunningThread)
+            break;
         if (isPlayableFile(url))
             valids << url;
     }
 
     _playlist->appendAsync(valids);
+
     return valids;
 }
 
@@ -810,6 +830,31 @@ QList<QUrl> PlayerEngine::addPlayFiles(const QList<QString> &lstFile)
     return addPlayFiles(valids);
 }
 
+void PlayerEngine::addPlayFs(const QList<QString> &lstFile)
+{
+    qInfo() << __func__;
+    QList<QUrl> valids;
+    QUrl realUrl;
+
+    for (QString strFile : lstFile) {
+          realUrl = FileFilter::instance()->fileTransfer(strFile);
+          if (QFileInfo(realUrl.path()).isDir()) {
+              if (realUrl.isLocalFile())          // 保证不是网络路径
+                  valids << FileFilter::instance()->filterDir(QDir(realUrl.path()));
+          } else {
+              valids << realUrl;
+          }
+    }
+
+    if (valids.isEmpty()) {
+        blockSignals(false);
+        return;
+    }
+    QList<QUrl> addFiles = addPlayFiles(valids);
+    blockSignals(false);
+    emit finishedAddFiles(addFiles);
+}
+
 qint64 PlayerEngine::duration() const
 {
     if (!_current) return 0;
@@ -906,14 +951,32 @@ QVariant PlayerEngine::getBackendProperty(const QString &name)
 
 void PlayerEngine::toggleRoundedClip(bool roundClip)
 {
-    dynamic_cast<MpvProxy *>(_current)->updateRoundClip(roundClip);
+    MpvProxy* pMpvProxy = nullptr;
+
+    pMpvProxy = dynamic_cast<MpvProxy *>(_current);
+    if(!pMpvProxy) {
+        dynamic_cast<QtPlayerProxy *>(_current)->updateRoundClip(roundClip);
+    } else {
+        pMpvProxy->updateRoundClip(roundClip);
+    }
 }
 
-/*void PlayerEngine::setVideoZoom(float val)
+bool PlayerEngine::currFileIsAudio()
 {
-    if (_current) {
-        _current->setProperty("video-zoom", val);
+    bool bAudio = false;
+    PlayItemInfo pif;
+
+    if (_playlist->count() > 0) {
+        pif = _playlist->currentInfo();
     }
-}*/
+
+    if (CompositingManager::isMpvExists()) {
+        bAudio = pif.thumbnail.isNull() && pif.url.isLocalFile();
+    } else {
+        bAudio = isAudioFile(pif.url.toString());
+    }
+
+    return bAudio;
+}
 
 } // end of namespace dmr
