@@ -38,6 +38,8 @@
 #include "dmr_settings.h"
 #endif
 #include "dvd_utils.h"
+#include "compositing_manager.h"
+#include "gstutils.h"
 
 #include <QSvgRenderer>
 
@@ -53,6 +55,11 @@ typedef int (*mvideo_avformat_find_stream_info)(AVFormatContext *ic, AVDictionar
 typedef int (*mvideo_av_find_best_stream)(AVFormatContext *ic, enum AVMediaType type, int wanted_stream_nb, int related_stream, AVCodec **decoder_ret, int flags);
 typedef void (*mvideo_avformat_close_input)(AVFormatContext **s);
 typedef AVDictionaryEntry *(*mvideo_av_dict_get)(const AVDictionary *m, const char *key, const AVDictionaryEntry *prev, int flags);
+typedef void (*mvideo_av_dump_format)(AVFormatContext *ic,int index, const char *url, int is_output);
+typedef AVCodec *(*mvideo_avcodec_find_decoder)(enum AVCodecID id);
+typedef const char *(*mvideo_av_get_media_type_string)(enum AVMediaType media_type);
+typedef AVCodecContext *(*mvideo_avcodec_alloc_context3)(const AVCodec *codec);
+typedef int (*mvideo_avcodec_parameters_to_context)(AVCodecContext *codec, const AVCodecParameters *par);
 
 
 mvideo_avformat_open_input g_mvideo_avformat_open_input = nullptr;
@@ -60,6 +67,11 @@ mvideo_avformat_find_stream_info g_mvideo_avformat_find_stream_info = nullptr;
 mvideo_av_find_best_stream g_mvideo_av_find_best_stream = nullptr;
 mvideo_avformat_close_input g_mvideo_avformat_close_input = nullptr;
 mvideo_av_dict_get g_mvideo_av_dict_get = nullptr;
+mvideo_av_dump_format g_mvideo_av_dump_format = nullptr;
+mvideo_avcodec_find_decoder g_mvideo_avcodec_find_decoder = nullptr;
+mvideo_av_get_media_type_string g_mvideo_av_get_media_type_string = nullptr;
+mvideo_avcodec_alloc_context3 g_mvideo_avcodec_alloc_context3 = nullptr;
+mvideo_avcodec_parameters_to_context g_mvideo_avcodec_parameters_to_context = nullptr;
 
 namespace dmr {
 QDataStream &operator<< (QDataStream &st, const MovieInfo &mi)
@@ -258,6 +270,10 @@ struct MovieInfo PlaylistModel::parseFromFile(const QFileInfo &fi, bool *ok)
     AVCodecParameters *video_dec_ctx = nullptr;
     AVCodecParameters *audio_dec_ctx = nullptr;
 
+    if (!CompositingManager::isMpvExists()) {
+        return parseFromFileByQt(fi, ok);
+    }
+
     if (!fi.exists()) {
         if (ok) *ok = false;
         return mi;
@@ -366,6 +382,19 @@ struct MovieInfo PlaylistModel::parseFromFile(const QFileInfo &fi, bool *ok)
     return mi;
 }
 
+MovieInfo PlaylistModel::parseFromFileByQt(const QFileInfo &fi, bool *ok)
+{
+    struct MovieInfo mi;
+
+    mi = GstUtils::get()->parseFileByGst(fi);
+
+    if (fi.exists()) {
+        *ok = true;
+    }
+
+    return mi;
+}
+
 bool PlayItemInfo::refresh()
 {
     if (url.isLocalFile()) {
@@ -449,9 +478,10 @@ QString PlaylistModel::libPath(const QString &strlib)
     } else {
         list.sort();
     }
-
-    Q_ASSERT(list.size() > 0);
-    return list.last();
+    if (list.size()>0)
+        return list.last();
+    else
+        return QString();
 }
 
 void PlaylistModel::initThumb()
@@ -462,17 +492,17 @@ void PlaylistModel::initThumb()
     m_mvideo_thumbnailer_create_image_data = (mvideo_thumbnailer_create_image_data) library.resolve("video_thumbnailer_create_image_data");
     m_mvideo_thumbnailer_destroy_image_data = (mvideo_thumbnailer_destroy_image_data) library.resolve("video_thumbnailer_destroy_image_data");
     m_mvideo_thumbnailer_generate_thumbnail_to_buffer = (mvideo_thumbnailer_generate_thumbnail_to_buffer) library.resolve("video_thumbnailer_generate_thumbnail_to_buffer");
-    m_video_thumbnailer = m_mvideo_thumbnailer();
 
     if (m_mvideo_thumbnailer == nullptr
             || m_mvideo_thumbnailer_destroy == nullptr
             || m_mvideo_thumbnailer_create_image_data == nullptr
             || m_mvideo_thumbnailer_destroy_image_data == nullptr
-            || m_mvideo_thumbnailer_generate_thumbnail_to_buffer == nullptr
-            || m_video_thumbnailer == nullptr) {
+            || m_mvideo_thumbnailer_generate_thumbnail_to_buffer == nullptr) {
         return;
     }
 
+    m_video_thumbnailer = m_mvideo_thumbnailer();
+
     m_image_data = m_mvideo_thumbnailer_create_image_data();
     m_video_thumbnailer->thumbnail_size = 400 * qApp->devicePixelRatio();
     m_bInitThumb = true;
@@ -489,6 +519,11 @@ void PlaylistModel::initFFmpeg()
     g_mvideo_av_find_best_stream = (mvideo_av_find_best_stream) avformatLibrary.resolve("av_find_best_stream");
     g_mvideo_avformat_close_input = (mvideo_avformat_close_input) avformatLibrary.resolve("avformat_close_input");
     g_mvideo_av_dict_get = (mvideo_av_dict_get) avutilLibrary.resolve("av_dict_get");
+    g_mvideo_av_dump_format = (mvideo_av_dump_format) avformatLibrary.resolve("av_dump_format");
+    g_mvideo_avcodec_find_decoder = (mvideo_avcodec_find_decoder) avcodecLibrary.resolve("avcodec_find_decoder");
+    g_mvideo_av_get_media_type_string = (mvideo_av_get_media_type_string) avutilLibrary.resolve("av_get_media_type_string");
+    g_mvideo_avcodec_alloc_context3 = (mvideo_avcodec_alloc_context3) avcodecLibrary.resolve("avcodec_alloc_context3");
+    g_mvideo_avcodec_parameters_to_context = (mvideo_avcodec_parameters_to_context) avcodecLibrary.resolve("avcodec_parameters_to_context");
 
     m_initFFmpeg = true;
 }
@@ -612,7 +647,6 @@ QImage PlaylistModel::getMovieCover(const QUrl &url)
 {
     if (!m_bInitThumb) {
         initThumb();
-        m_mvideo_thumbnailer_destroy_image_data(m_image_data);
         m_image_data = nullptr;
     }
 
@@ -1111,10 +1145,9 @@ void PlaylistModel::delayedAppendAsync(const QList<QUrl> &urls)
             m_getThumanbil = new GetThumanbil(this, t_urls);
             connect(m_getThumanbil, &GetThumanbil::finished, this, &PlaylistModel::onAsyncFinished);
             connect(m_getThumanbil, &GetThumanbil::updateItem, this, &PlaylistModel::onAsyncUpdate, Qt::BlockingQueuedConnection);
-            m_isLoadRunning = true;
             m_getThumanbil->start();
         } else {
-            if (m_isLoadRunning) {
+            if (m_getThumanbil->isRunning()) {
                 m_tempList.append(t_urls);
             } else {
                 m_getThumanbil->setUrls(t_urls);
@@ -1178,14 +1211,12 @@ static QList<PlayItemInfo> &SortSimilarFiles(QList<PlayItemInfo> &fil)
 
 void PlaylistModel::onAsyncFinished()
 {
-    m_isLoadRunning = false;
     //qInfo() << fil.size();
     m_getThumanbil->clearItem();
     //handleAsyncAppendResults(fil);
     if (!m_tempList.isEmpty()) {
         m_getThumanbil->setUrls(m_tempList);
         m_tempList.clear();
-        m_isLoadRunning = true;
         m_getThumanbil->start();
     }
 }
@@ -1427,8 +1458,8 @@ struct PlayItemInfo PlaylistModel::calculatePlayInfo(const QUrl &url, const QFil
         mi.title = fi.fileName();
     }
 
-    QPixmap pm;
-    QPixmap dark_pm;
+    QPixmap pm = QPixmap();
+    QPixmap dark_pm = QPixmap();
     if (ci.thumb_valid) {
         pm = ci.thumb;
         dark_pm = ci.thumb_dark;
@@ -1451,7 +1482,7 @@ struct PlayItemInfo PlaylistModel::calculatePlayInfo(const QUrl &url, const QFil
                 isMusic = true;
             }
 
-            if (isMusic == false) {
+            if (isMusic == false && m_mvideo_thumbnailer_generate_thumbnail_to_buffer) {
                 m_mvideo_thumbnailer_generate_thumbnail_to_buffer(m_video_thumbnailer, fi.canonicalFilePath().toUtf8().data(),  m_image_data);
                 auto img = QImage::fromData(m_image_data->image_data_ptr, static_cast<int>(m_image_data->image_data_size), "png");
                 pm = QPixmap::fromImage(img);
@@ -1468,7 +1499,7 @@ struct PlayItemInfo PlaylistModel::calculatePlayInfo(const QUrl &url, const QFil
     if (ok && url.isLocalFile() && (!ci.mi_valid || !ci.thumb_valid)) {
         PersistentManager::get().save(pif);
     }
-    if (!url.isLocalFile() && !url.scheme().startsWith("dvd")) {
+    if (!url.isLocalFile() && !url.scheme().startsWith("dvd") && CompositingManager::isMpvExists()) {
         pif.mi.filePath = pif.url.path();
 
         pif.mi.width = _engine->_current->width();
@@ -1550,9 +1581,9 @@ static int open_codec_context(int *stream_idx,
     AVStream *st;
     AVCodec *dec = NULL;
     AVDictionary *opts = NULL;
-    ret = av_find_best_stream(fmt_ctx, type, -1, -1, NULL, 0);
+    ret = g_mvideo_av_find_best_stream(fmt_ctx, type, -1, -1, NULL, 0);
     if (ret < 0) {
-        qWarning() << "Could not find " << av_get_media_type_string(type)
+        qWarning() << "Could not find " << g_mvideo_av_get_media_type_string(type)
                    << " stream in input file";
         return ret;
     }
@@ -1561,26 +1592,26 @@ static int open_codec_context(int *stream_idx,
     st = fmt_ctx->streams[stream_index];
 #if LIBAVFORMAT_VERSION_MAJOR >= 57
     *dec_ctx = st->codecpar;
-    dec = avcodec_find_decoder((*dec_ctx)->codec_id);
+    dec = g_mvideo_avcodec_find_decoder((*dec_ctx)->codec_id);
 #else
     /* find decoder for the stream */
-    dec = avcodec_find_decoder(st->codecpar->codec_id);
+    dec = g_mvideo_avcodec_find_decoder(st->codecpar->codec_id);
     if (!dec) {
         fprintf(stderr, "Failed to find %s codec\n",
-                av_get_media_type_string(type));
+                g_mvideo_av_get_media_type_string(type));
         return AVERROR(EINVAL);
     }
     /* Allocate a codec context for the decoder */
-    *dec_ctx = avcodec_alloc_context3(dec);
+    *dec_ctx = g_mvideo_avcodec_alloc_context3(dec);
     if (!*dec_ctx) {
         fprintf(stderr, "Failed to allocate the %s codec context\n",
-                av_get_media_type_string(type));
+                g_mvideo_av_get_media_type_string(type));
         return AVERROR(ENOMEM);
     }
     /* Copy codec parameters from input stream to output codec context */
-    if ((ret = avcodec_parameters_to_context(*dec_ctx, st->codecpar)) < 0) {
+    if ((ret = g_mvideo_avcodec_parameters_to_context(*dec_ctx, st->codecpar)) < 0) {
         fprintf(stderr, "Failed to copy %s codec parameters to decoder context\n",
-                av_get_media_type_string(type));
+                g_mvideo_av_get_media_type_string(type));
         return ret;
     }
 #endif
@@ -1601,15 +1632,22 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
         if (ok) *ok = false;
         return mi;
     }
+    if (!CompositingManager::isMpvExists()) {
+        mi = GstUtils::get()->parseFileByGst(fi);
+        if(mi.valid){
+            *ok = true;
+        }
+        return mi;
+    }
 
-    auto ret = avformat_open_input(&av_ctx, fi.filePath().toUtf8().constData(), NULL, NULL);
+    auto ret = g_mvideo_avformat_open_input(&av_ctx, fi.filePath().toUtf8().constData(), NULL, NULL);
     if (ret < 0) {
         qWarning() << "avformat: could not open input";
         if (ok) *ok = false;
         return mi;
     }
 
-    if (avformat_find_stream_info(av_ctx, NULL) < 0) {
+    if (g_mvideo_avformat_find_stream_info(av_ctx, NULL) < 0) {
         qWarning() << "av_find_stream_info failed";
         if (ok) *ok = false;
         return mi;
@@ -1633,7 +1671,7 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
         }
     }
 
-    av_dump_format(av_ctx, 0, fi.fileName().toUtf8().constData(), 0);
+    g_mvideo_av_dump_format(av_ctx, 0, fi.fileName().toUtf8().constData(), 0);
 
     mi.width = dec_ctx->width;
     mi.height = dec_ctx->height;
@@ -1678,7 +1716,7 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
     mi.sampling = dec_ctx->sample_rate;
 
     AVDictionaryEntry *tag = NULL;
-    while ((tag = av_dict_get(av_ctx->metadata, "", tag, AV_DICT_IGNORE_SUFFIX)) != NULL) {
+    while ((tag = g_mvideo_av_dict_get(av_ctx->metadata, "", tag, AV_DICT_IGNORE_SUFFIX)) != NULL) {
         if (tag->key && strcmp(tag->key, "creation_time") == 0) {
             auto dt = QDateTime::fromString(tag->value, Qt::ISODate);
             mi.creation = dt.toString();
@@ -1690,7 +1728,7 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
 
     tag = NULL;
     AVStream *st = av_ctx->streams[stream_id];
-    while ((tag = av_dict_get(st->metadata, "", tag, AV_DICT_IGNORE_SUFFIX)) != NULL) {
+    while ((tag = g_mvideo_av_dict_get(st->metadata, "", tag, AV_DICT_IGNORE_SUFFIX)) != NULL) {
         if (tag->key && strcmp(tag->key, "rotate") == 0) {
             mi.raw_rotate = QString(tag->value).toInt();
             auto vr = (mi.raw_rotate + 360) % 360;
@@ -1705,7 +1743,7 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
     }
 
 
-    avformat_close_input(&av_ctx);
+    g_mvideo_avformat_close_input(&av_ctx);
     mi.valid = true;
 
     if (ok) *ok = true;
