@@ -1219,7 +1219,7 @@ void Platform_ToolboxProxy::updateThumbnail()
     //如果打开的是音乐
     QString suffix = m_pEngine->playlist().currentInfo().info.suffix();
 
-    if (m_pEngine->isAudioFile(m_pEngine->playlist().currentInfo().info.absoluteFilePath())) {
+    if (m_pEngine->currFileIsAudio()) {
         return;
     }
 
@@ -1352,6 +1352,11 @@ void Platform_ToolboxProxy::updateHoverPreview(const QUrl &url, int secs)
     qint64 nDuration = m_pEngine->duration();
     QPoint showPoint;
 
+    if(nDuration<=0)
+    {
+        return;
+    }
+
     if (m_pProgBar->isVisible()) {
         nPosition = (secs * m_pProgBar->slider()->width()) / nDuration;
         showPoint = m_pProgBar->mapToGlobal(QPoint(nPosition, TOOLBOX_TOP_EXTENT - 10));
@@ -1472,7 +1477,7 @@ void Platform_ToolboxProxy::slotThemeTypeChanged()
 
     if(m_pEngine->state() != PlayerEngine::CoreState::Idle) {
         bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
-        if(bRawFormat && !FileFilter::instance()->isAudio(m_pEngine->playlist().currentInfo().url)) {
+        if(bRawFormat && !m_pEngine->currFileIsAudio()) {
             m_pTimeLabel->setPalette(textPalette);
             m_pTimeLabelend->setPalette(textPalette);
             m_pFullscreentimelable->setPalette(textPalette);
@@ -1557,12 +1562,8 @@ void Platform_ToolboxProxy::slotVolumeButtonClicked()
      * 大于等于零表示为已完成初始化
      */
     if (!m_pVolSlider->isVisible()) {
-        auto pPoint = mapToGlobal(QPoint(this->rect().width(), this->rect().height()));
         m_pVolSlider->adjustSize();
-
-        pPoint.setX(pPoint.x() - m_pVolBtn->width() / 2 - m_pPlayBtn->width() - 43);
-        pPoint.setY(pPoint.y() - TOOLBOX_HEIGHT - 5);
-        m_pVolSlider->show(pPoint.x(), pPoint.y());
+        m_pVolSlider->show();
         m_pVolSlider->popup();
     } else {
         m_pVolSlider->popup();
@@ -1788,7 +1789,7 @@ void Platform_ToolboxProxy::progressHoverChanged(int nValue)
         point.setX(endPoint.x());
     }
 
-    bool bIsAudio = m_pEngine->isAudioFile(pif.info.absoluteFilePath());
+    bool bIsAudio = m_pEngine->currFileIsAudio();
     if (!Settings::get().isSet(Settings::PreviewOnMouseover) || bIsAudio) {
         updatePreviewTime(nValue, point);
         return;
@@ -1796,6 +1797,12 @@ void Platform_ToolboxProxy::progressHoverChanged(int nValue)
     //鼠标移动时同步缩略图显示位置
     int nPosition = 0;
     qint64 nDuration = m_pEngine->duration();
+
+    if(nDuration<=0)
+    {
+        return;
+    }
+
     if (m_pProgBar->isVisible()) {
         nPosition = (nValue * m_pProgBar->slider()->width()) / nDuration;
         point = m_pProgBar->mapToGlobal(QPoint(nPosition, TOOLBOX_TOP_EXTENT - 10));
@@ -1860,7 +1867,7 @@ void Platform_ToolboxProxy::updateButtonStates()
 
     if(m_pEngine->state() != PlayerEngine::CoreState::Idle) {
         bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
-        if(bRawFormat && !FileFilter::instance()->isAudio(m_pEngine->playlist().currentInfo().url)){                                             // 如果正在播放的视频是裸流不支持音量调节和进度调节
+        if(bRawFormat && !m_pEngine->currFileIsAudio()){                                             // 如果正在播放的视频是裸流不支持音量调节和进度调节
             m_pProgBar->setEnabled(false);
             m_pProgBar->setEnableIndication(false);
             m_pVolSlider->setEnabled(false);
