@@ -947,7 +947,7 @@ void ToolboxProxy::setthumbnailmode()
         return;
     }
 
-    if(CompositingManager::get().platform() == Platform::X86) {
+    if(CompositingManager::get().platform() == Platform::X86  && CompositingManager::isMpvExists()) {
         if (Settings::get().isSet(Settings::ShowThumbnailMode)) {
             m_bThumbnailmode = true;
             updateThumbnail();
@@ -1290,7 +1290,7 @@ void ToolboxProxy::updateThumbnail()
     //如果打开的是音乐
     QString suffix = m_pEngine->playlist().currentInfo().info.suffix();
 
-    if (m_pEngine->isAudioFile(m_pEngine->playlist().currentInfo().info.absoluteFilePath())) {
+    if (m_pEngine->currFileIsAudio()) {
         return;
     }
 
@@ -1423,6 +1423,11 @@ void ToolboxProxy::updateHoverPreview(const QUrl &url, int secs)
     qint64 nDuration = m_pEngine->duration();
     QPoint showPoint;
 
+    if(nDuration<=0)
+    {
+        return;
+    }
+
     if (m_pProgBar->isVisible()) {
         nPosition = (secs * m_pProgBar->slider()->width()) / nDuration;
         showPoint = m_pProgBar->mapToGlobal(QPoint(nPosition, TOOLBOX_TOP_EXTENT - 10));
@@ -1544,7 +1549,7 @@ void ToolboxProxy::slotThemeTypeChanged()
 
     if(m_pEngine->state() != PlayerEngine::CoreState::Idle) {
         bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
-        if(bRawFormat && !FileFilter::instance()->isAudio(m_pEngine->playlist().currentInfo().url)) {
+        if(bRawFormat && !m_pEngine->currFileIsAudio()) {
             m_pTimeLabel->setPalette(textPalette);
             m_pTimeLabelend->setPalette(textPalette);
             m_pFullscreentimelable->setPalette(textPalette);
@@ -1629,8 +1634,7 @@ void ToolboxProxy::slotVolumeButtonClicked()
      * 大于等于零表示为已完成初始化
      */
     if (!m_pVolSlider->isVisible()) {
-        m_pVolSlider->show(m_pMainWindow->width() - m_pVolBtn->width() / 2 - m_pPlayBtn->width() - 40,
-                           m_pMainWindow->height() - TOOLBOX_HEIGHT - 2);
+        m_pVolSlider->show();
         m_pVolSlider->popup();
     } else {
         m_pVolSlider->popup();
@@ -1858,12 +1862,6 @@ void ToolboxProxy::playlistClosedByEsc()
 
 void ToolboxProxy::progressHoverChanged(int nValue)
 {
-
-    if(m_pProgBar->slider()->value() == 0)   // 没有时长信息的影片不需要预览
-    {
-        return;
-    }
-
     if (m_pEngine->state() == PlayerEngine::CoreState::Idle)
         return;
 
@@ -1898,7 +1896,7 @@ void ToolboxProxy::progressHoverChanged(int nValue)
         point.setX(endPoint.x());
     }
 
-    bool bIsAudio = m_pEngine->isAudioFile(pif.info.absoluteFilePath());
+    bool bIsAudio = m_pEngine->currFileIsAudio();
     if (!Settings::get().isSet(Settings::PreviewOnMouseover) || bIsAudio) {
         updatePreviewTime(nValue, point);
         return;
@@ -1906,6 +1904,12 @@ void ToolboxProxy::progressHoverChanged(int nValue)
     //鼠标移动时同步缩略图显示位置
     int nPosition = 0;
     qint64 nDuration = m_pEngine->duration();
+
+    if(nDuration<=0)
+    {
+        return;
+    }
+
     if (m_pProgBar->isVisible()) {
         nPosition = (nValue * m_pProgBar->slider()->width()) / nDuration;
         point = m_pProgBar->mapToGlobal(QPoint(nPosition, TOOLBOX_TOP_EXTENT - 10));
@@ -1914,7 +1918,9 @@ void ToolboxProxy::progressHoverChanged(int nValue)
         point = m_pViewProgBar->mapToGlobal(QPoint(nPosition, TOOLBOX_TOP_EXTENT - 10));
     }
     m_pPreviewer->updateWithPreview(point);
-    ThumbnailWorker::get().requestThumb(pif.url, nValue);
+    if(CompositingManager::isMpvExists()) {
+        ThumbnailWorker::get().requestThumb(pif.url, nValue);
+    }
 }
 
 void ToolboxProxy::updateTimeVisible(bool visible)
@@ -1970,7 +1976,7 @@ void ToolboxProxy::updateButtonStates()
 
     if(m_pEngine->state() != PlayerEngine::CoreState::Idle) {
         bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
-        if(bRawFormat && !FileFilter::instance()->isAudio(m_pEngine->playlist().currentInfo().url)){                                             // 如果正在播放的视频是裸流不支持音量调节和进度调节
+        if(bRawFormat && !m_pEngine->currFileIsAudio()){                                             // 如果正在播放的视频是裸流不支持音量调节和进度调节
             m_pProgBar->setEnabled(false);
             m_pProgBar->setEnableIndication(false);
             m_pVolSlider->setEnabled(false);
@@ -2167,6 +2173,8 @@ void ToolboxProxy::updatePlayState()
     }
 
     if (m_pEngine->state() == PlayerEngine::CoreState::Idle) {
+        m_pTimeLabel->setText("");
+        m_pTimeLabelend->setText("");
 
         if (m_pPreviewer->isVisible()) {
             m_pPreviewer->hide();
@@ -2304,7 +2312,7 @@ void ToolboxProxy::resizeEvent(QResizeEvent *event)
     if (event->oldSize().width() != event->size().width()) {
         if (m_pEngine->state() != PlayerEngine::CoreState::Idle) {
             if (m_bThumbnailmode) {  //如果进度条为胶片模式，重新加载缩略图并显示
-                if(CompositingManager::get().platform() == Platform::X86) {
+                if(CompositingManager::get().platform() == Platform::X86 && CompositingManager::isMpvExists()) {
                     updateThumbnail();
                 }
                 updateMovieProgress();
@@ -2556,6 +2564,13 @@ void ToolboxProxy::initThumbThread()
 void ToolboxProxy::updateSliderPoint(QPoint &point)
 {
     m_pVolSlider->updatePoint(point);
+
+    // move to the final position
+    QRect mainRect = m_pMainWindow->rect();
+    QRect viewRect = mainRect.marginsRemoved(QMargins(1, 1, 1, 1));
+    QPoint volPoint = point + QPoint(viewRect.width() - (TOOLBOX_BUTTON_WIDTH * 2 + 30 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2),
+                             viewRect.height() - TOOLBOX_HEIGHT - VOLSLIDER_HEIGHT) + QPoint(6, 0);
+    m_pVolSlider->move(volPoint);
 }
 
 /**
@@ -2563,7 +2578,9 @@ void ToolboxProxy::updateSliderPoint(QPoint &point)
  */
 ToolboxProxy::~ToolboxProxy()
 {
-    ThumbnailWorker::get().stop();
+    if(CompositingManager::isMpvExists()) {
+        ThumbnailWorker::get().stop();
+    }
     delete m_pPreviewer;
     delete m_pPreviewTime;
 
