@@ -100,6 +100,33 @@ TEST(PadMode, mainWindow)
 }
 #endif
 
+TEST(GStreamer, mainWindow)
+{
+    Stub stub;
+    stub.set(ADDR(CompositingManager, isMpvExists), StubFunc::isMpvExists_stub);
+    QTest::qWait(1000);
+    MainWindow *mw = new MainWindow;
+    QTest::qWait(100);
+    mw->show();
+
+    QTest::qWait(800);
+
+    PlayerEngine *engine =  mw->engine();
+    QList<QUrl> listPlayFiles;
+    listPlayFiles << QUrl::fromLocalFile("/data/source/deepin-movie-reborn/movie/demo.mp4");
+
+    engine->playlist().loadPlaylist();
+    engine->addPlayFiles(listPlayFiles);
+    engine->playByName(QUrl::fromLocalFile("/data/source/deepin-movie-reborn/movie/demo.mp4"));
+    QTest::qWait(2000);
+
+    stub.reset(ADDR(CompositingManager, isMpvExists));
+    mw->close();
+    delete mw;
+
+    QTest::qWait(500);
+}
+
 TEST(MainWindow, init)
 {
     MainWindow *w = dApp->getMainWindow();
@@ -144,6 +171,25 @@ TEST(MainWindow, nakedstream)
     engine->addPlayFiles(listPlayFiles);
     engine->playByName(QUrl::fromLocalFile("/data/source/deepin-movie-reborn/movie/test.264"));
 
+    // drop is playing video
+    QMimeData mimeData;
+    QList<QUrl> urls;
+    urls << QUrl::fromLocalFile("/data/source/deepin-movie-reborn/movie/test.264");
+    mimeData.setUrls(urls);
+
+    QDragEnterEvent dragEnter(QPoint(0, 0), Qt::CopyAction, &mimeData, Qt::LeftButton, {});
+    QApplication::sendEvent(w, &dragEnter);
+    QVERIFY(dragEnter.isAccepted());
+    QCOMPARE(dragEnter.dropAction(), Qt::CopyAction);
+
+    QDragMoveEvent dragMove(QPoint(0, 0), Qt::CopyAction, &mimeData, Qt::LeftButton, Qt::NoModifier);
+    qApp->sendEvent(w, &dragMove);
+
+    QDropEvent drop(QPoint(0, 0), Qt::CopyAction, &mimeData, Qt::NoButton, {});
+    QApplication::sendEvent(w, &drop);
+    QVERIFY(drop.isAccepted());
+    QCOMPARE(drop.dropAction(), Qt::CopyAction);
+
     QTest::mousePress(dmrSlider, Qt::LeftButton, Qt::NoModifier, QPoint(), 100);
     QTest::mouseMove(dmrSlider, QPoint(), 100);
     QTest::mouseRelease(dmrSlider, Qt::LeftButton, Qt::NoModifier, QPoint(), 100);
@@ -238,6 +284,9 @@ TEST(MainWindow, loadFile)
 {
     MainWindow *w = dApp->getMainWindow();
     w->show();
+    QList<QString> wrongPath;
+    wrongPath << "/data/source/deepin-movie-reborn/movie/wrong.mp4";
+    w->play(wrongPath);
     PlayerEngine *engine =  w->engine();
     QList<QUrl> listPlayFiles;
     listPlayFiles << QUrl::fromLocalFile("/data/source/deepin-movie-reborn/movie/demo.mp4")
@@ -349,6 +398,7 @@ TEST(MainWindow, touch)
     engine->stop();
     engine->playByName(QUrl::fromLocalFile("/data/source/deepin-movie-reborn/movie/demo.mp4"));
 
+    QTest::qWait(500);
     if (!w->isFullScreen()) {
         qDebug() << __func__ << "进入全屏";
         QTest::mouseDClick(w, Qt::LeftButton, Qt::NoModifier, QPoint(), 500); //fullscreen
@@ -467,6 +517,8 @@ TEST(MainWindow, shortCutVolumeAndFrame)
     MainWindow *w = dApp->getMainWindow();
     QTestEventList testEventList;
 
+    QVERIFY(w->toolbox()->getSlider()->isEnabled());
+
     //volume
     testEventList.addKeyClick(Qt::Key_Down, Qt::ControlModifier | Qt::AltModifier, 20);    //volume down
     for (int i = 0; i < 11; i++) {
@@ -940,6 +992,8 @@ TEST(ToolBox, volBtn)
 
     QTest::mouseMove(volBtn, QPoint(), 200);
     QTest::mouseClick(volBtn, Qt::LeftButton, Qt::NoModifier, QPoint(), 500);
+    QTest::qWait(300);
+    QVERIFY(toolboxProxy->volumeSlider()->isVisible());
 
     QWheelEvent wheelUpEvent(volBtn->rect().center(), 20, Qt::NoButton, Qt::NoModifier);
     QWheelEvent wheelDownEvent(volBtn->rect().center(), -20, Qt::NoButton, Qt::NoModifier);
